@@ -7,19 +7,26 @@ else:
     from . import utils
 
 def get_data(root):
+    download(root)
+    extract(root)
+    utils.print_finish(root)
+
+def download(root):
     import gdown
-    utils.print_start(root)
+    utils.print_start1(root)
     with utils.data_directory(root):
         url = 'https://drive.google.com/uc?id=1yVy4--M4CNfE5x9wUr1QBmAXEcWb6PWF'
         archive = 'zebra_training_set.zip'
         gdown.download(url, archive, quiet=False)
 
+def extract(root):
+    utils.print_start2(root)
+    with utils.data_directory(root):
         os.system('jar xvf zebra_training_set.zip')
         os.remove('zebra_training_set.zip')
         shutil.rmtree(os.path.join('zebra_training_set', 'annotations'))
         shutil.rmtree(os.path.join('zebra_training_set', 'texmap'))
         shutil.rmtree(os.path.join('zebra_training_set', 'uvflow'))
-    utils.print_finish(root)
 
 
 if __name__ == '__main__':
