@@ -6,7 +6,12 @@ else:
     from . import utils
 
 def get_data(root):
-    utils.print_start(root)
+    download(root)
+    extract(root)
+    utils.print_finish(root)
+
+def download(root):
+    utils.print_start1(root)
     with utils.data_directory(root):
         downloads = [
             ('https://storage.googleapis.com/dm-turtle-recall/train.csv', 'train.csv'),
@@ -16,8 +21,11 @@ def get_data(root):
         ]
         for url, file in downloads:
             utils.download_url(url, file)
+
+def extract(root):
+    utils.print_start2(root)
+    with utils.data_directory(root):
         utils.extract_archive('images.tar', 'images', delete=True)
-    utils.print_finish(root)
 
 
 if __name__ == '__main__':
